<?php

namespace SM\Service;

use SM\Factory\Sm00005000TabParametrizacoesIndicesPadroesFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00005000TabParametrizacoesIndicesPadroesService
{
    protected $connection;
    protected $parametrizacaoIndiceFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00005000TabParametrizacoesIndicesPadroesFactory $parametrizacaoIndiceFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->parametrizacaoIndiceFactory  = $parametrizacaoIndiceFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getIndicesPadroes()
    {
        return $this->parametrizacaoIndiceFactory->getIndicesPadroes();
    }

    public function getIndiceFinanceiro()
    {
        return $this->parametrizacaoIndiceFactory->getIndiceFinanceiro();
    }

    public function saveIndicesFinanceirosPadrao($parametros)
    {
        $paramsValida = array(
            "NRINDICESPADROES" => $parametros['NRINDICESPADROES'],
            "CDINDICE"           => $parametros['CDINDICE'],
        );

        $valor = $this->parametrizacaoIndiceFactory->validaRegistrosDuplicados($paramsValida);

        if ($valor[0]["QTD"] > 0) {
            throw new \Exception("EXISTE");
        }
    
        $this->connection->beginTransaction();
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        try {
            if ($parametros['NRINDICESPADROES'] == null) {
                $nrindicespadroes = $this->newCode->getCodeByTableName("FCT_INDICESPADROES", $nrorg, 1, 10, true);
                $dataParams = array (
                    "NRINDICESPADROES"      => $nrindicespadroes,
                    "CDINDICE"              => $parametros["CDINDICE"],
                    "CDTPINDICE"            => $parametros["CDTPINDICE"],
                    "IDPERVALOR"            => $parametros["IDPERVALOR"],
                    "NRPERCENTINDICE"       => $parametros["NRPERCENTINDICE"],
                    "NRORG"                 => $nrorg,
                    "CDOPERINCLUSAO"        => $cdoperador,
                    "IDATIVO"               => "S",
                );
                $this->parametrizacaoIndiceFactory->insertIndiceFinanceiroPadrao($dataParams);
            } else {
                $dataParams = array (
                    "NRINDICESPADROES"    => $parametros["NRINDICESPADROES"],
                    "CDINDICE"              => $parametros["CDINDICE"],
                    "CDTPINDICE"            => $parametros["CDTPINDICE"],
                    "IDPERVALOR"            => $parametros["IDPERVALOR"],
                    "NRPERCENTINDICE"      => $parametros["NRPERCENTINDICE"],
                    "NRORG"                 => $nrorg,
                    "CDOPERULTATU"          => $cdoperador,
                    "IDATIVO"               => "S",
                );
                $this->parametrizacaoIndiceFactory->updateIndiceFinanceiroPadrao($dataParams);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteParametrosIndice($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $parametroIndices) {
                $dataParam = array( "NRINDICESPADROES" => $parametroIndices["NRINDICESPADROES"],);
                $this->parametrizacaoIndiceFactory->deleteParametrosIndice($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
