<?php

namespace SM\Service;

use SM\Factory\Sm00052001DescontoMaximoServicoOperadorFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00052001DescontoMaximoServicoOperadorService
{
    protected $connection;
    protected $descMaximoServicoFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00052001DescontoMaximoServicoOperadorFactory $descMaximoServicoFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->descMaximoServicoFactory     = $descMaximoServicoFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getNomeOperadorDescontoMaximoServicoOperador()
    {
        return $this->descMaximoServicoFactory->getNomeOperadorDescontoMaximoServicoOperador();
    }

    public function getServicoDescontoMaximoServicoOperador($params)
    {

        $parametros = array(
            "NRPARCNEGOCIO" => $params['NRPARCNEGOCIO']
        );
    
        return $this->descMaximoServicoFactory->getServicoDescontoMaximoServicoOperador($parametros);
    }
    
    public function saveDescMaxServicoOperador($params)
    {
        $cdoperador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();
        $this->connection->beginTransaction();
        
        try {
            foreach ($params as $row) {
                $paramsaux = array(
                    "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                    "CDSERVORCA" => $row['CDSERVORCA'],
                    "NRSEQDESC" => $row['NRSEQDESC'],
                );
                $valida = $this->descMaximoServicoFactory->validaDados($paramsaux);
                if ($valida == 0) {
                    if ($row["NRSEQDESC"]) {
                        $parametros = array(
                            "NRPARCNEGOCIO"          => $row['NRPARCNEGOCIO'],
                            "CDSERVORCA"             => $row['CDSERVORCA'],
                            "VRPERCDESC"             => $row['VRPERCDESC'],
                            "NRORG"                  => $nrorg,
                            "IDATIVO"                => "S",
                            "CDOPERULTATU"           => $cdoperador,
                            "NRSEQDESC"              => $row['NRSEQDESC']
                        );
                        $this->descMaximoServicoFactory->updateDescMaxServicoOperador($parametros);
                    } else {
                        $nrdescmaxservico = $this->newCode->getCodeByTableName("FCT_PERCDESCOPER", $nrorg, 1, 10, true);
                        $parametros = array(
                            "NRSEQDESC"              => $nrdescmaxservico,
                            "NRPARCNEGOCIO"          => $row['NRPARCNEGOCIO'],
                            "CDSERVORCA"             => $row['CDSERVORCA'],
                            "VRPERCDESC"             => $row['VRPERCDESC'],
                            "NRORG"                  => $nrorg,
                            "IDATIVO"                => "S",
                            "CDOPERINCLUSAO"         => $cdoperador
                        );
                        $this->descMaximoServicoFactory->insertDescMaxServicoOperador($parametros);
                    }
                } else {
                    throw new \Exception("ERRO");
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteDescMaxServicoModalServico($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $desconto) {
                $dataParam = array(
                    "NRSEQDESC" => $desconto["NRSEQDESC"],
                );
                $this->descMaximoServicoFactory->deleteDescMaxServicoModalServico($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
